Index: trunk/ippTools/src/regtool.c
===================================================================
--- trunk/ippTools/src/regtool.c	(revision 11997)
+++ trunk/ippTools/src/regtool.c	(revision 12024)
@@ -39,6 +39,6 @@
 
 // static p1PendingExpRow *newToP1PendingExp(newExpRow *newExp);
-static p2PendingExpRow *newToP2PendingExp(pxConfig *config, newExpRow *newExp);
-static p2PendingImfileRow *rawImfileToP2PendingImfile(pxConfig *config, rawImfileRow *rawImfile);
+static chipPendingExpRow *newTochipPendingExp(pxConfig *config, newExpRow *newExp);
+static chipPendingImfileRow *rawImfileTochipPendingImfile(pxConfig *config, rawImfileRow *rawImfile);
 
 static rawExpRow *newToRawExp(pxConfig *config, newExpRow *exp);
@@ -672,5 +672,5 @@
         }
 
-        // if this is a detrend image don't put it in the p2 queue (and we're
+        // if this is a detrend image don't put it in the chip queue (and we're
         // done)
         if (detrend) {
@@ -679,8 +679,8 @@
         }
 
-        // insert an entry into the p2PendingExp table
-        p2PendingExpRow *p2PendingExp = newToP2PendingExp(config, newExp);
-        if (!p2PendingExp) {
-            psError(PS_ERR_UNKNOWN, false, "failed to convert newExp to p2PendingExp");
+        // insert an entry into the chipPendingExp table
+        chipPendingExpRow *chipPendingExp = newTochipPendingExp(config, newExp);
+        if (!chipPendingExp) {
+            psError(PS_ERR_UNKNOWN, false, "failed to convert newExp to chipPendingExp");
             psFree(newExp);
             psFree(output);
@@ -688,6 +688,6 @@
         }
 
-        // insert the p2PendingExp object into the database
-        if (!p2PendingExpInsertObject(config->dbh, p2PendingExp)) {
+        // insert the chipPendingExp object into the database
+        if (!chipPendingExpInsertObject(config->dbh, chipPendingExp)) {
             // rollback
             if (!psDBRollback(config->dbh)) {
@@ -695,12 +695,12 @@
             }
             psError(PS_ERR_UNKNOWN, false, "database error");
-            psFree(p2PendingExp);
+            psFree(chipPendingExp);
             psFree(newExp);
             psFree(output);
             return false;
         }
-        psFree(p2PendingExp);
-
-        // find all of the rawImfiles associated with the p2PendingExp object
+        psFree(chipPendingExp);
+
+        // find all of the rawImfiles associated with the chipPendingExp object
         psArray *rawImfiles = NULL;
         {
@@ -744,10 +744,10 @@
             return false;
         }
         // convert the rawImfiles into p2PendingImfiles and insert them into
         // the database
         for (long i = 0; i < psArrayLength(rawImfiles); i++) {
             rawImfileRow *rawImfile = rawImfiles->data[i];
-            p2PendingImfileRow *pendingImfile = rawImfileToP2PendingImfile(config, rawImfile);
-            if (!p2PendingImfileInsertObject(config->dbh, pendingImfile)){
+            chipPendingImfileRow *pendingImfile = rawImfileTochipPendingImfile(config, rawImfile);
+            if (!chipPendingImfileInsertObject(config->dbh, pendingImfile)){
                 // rollback
                 if (!psDBRollback(config->dbh)) {
@@ -915,5 +915,5 @@
 
 
-static p2PendingExpRow *newToP2PendingExp(pxConfig *config, newExpRow *exp)
+static chipPendingExpRow *newTochipPendingExp(pxConfig *config, newExpRow *exp)
 {
     PS_ASSERT_PTR_NON_NULL(config, NULL);
@@ -928,7 +928,7 @@
     }
 
-    p2PendingExpRow *p2Exp = p2PendingExpRowAlloc(
+    chipPendingExpRow *chipExp = chipPendingExpRowAlloc(
         exp->exp_tag,
-        0x0,            // p2 version XXX calc version number
+        0x0,            // chip version XXX calc version number
         0xdeadbeef,     // p1 version
         label,
@@ -938,13 +938,13 @@
     );
 
-    return p2Exp;
-}
-
-
-static p2PendingImfileRow *rawImfileToP2PendingImfile(pxConfig *config, rawImfileRow *rawImfile)
-{
-    return p2PendingImfileRowAlloc(
+    return chipExp;
+}
+
+
+static chipPendingImfileRow *rawImfileTochipPendingImfile(pxConfig *config, rawImfileRow *rawImfile)
+{
+    return chipPendingImfileRowAlloc(
         rawImfile->exp_tag,
-        0x0,          // p2 version XXX calc version number
+        0x0,          // chip version XXX calc version number
         0xdeadbeef,   // p1 version
         rawImfile->class_id,
@@ -744,10 +744,10 @@
             return false;
         }
-        // convert the rawImfiles into p2PendingImfiles and insert them into
+        // convert the rawImfiles into chipPendingImfiles and insert them into
         // the database
         for (long i = 0; i < psArrayLength(rawImfiles); i++) {
